package com.ruoyi.interfaces.service;

import java.util.List;
import com.ruoyi.interfaces.domain.MdModelFlow;

/**
 * 模型流程Service接口
 * 
 * @author 朱得糠
 * @date 2025-08-02
 */
public interface IMdModelFlowService 
{
    /**
     * 查询模型流程
     * 
     * @param flowId 模型流程主键
     * @return 模型流程
     */
    public MdModelFlow selectMdModelFlowByFlowId(Long flowId);

    /**
     * 查询模型流程列表
     * 
     * @param mdModelFlow 模型流程
     * @return 模型流程集合
     */
    public List<MdModelFlow> selectMdModelFlowList(MdModelFlow mdModelFlow);

    /**
     * 新增模型流程
     * 
     * @param mdModelFlow 模型流程
     * @return 结果
     */
    public int insertMdModelFlow(MdModelFlow mdModelFlow);

    /**
     * 修改模型流程
     * 
     * @param mdModelFlow 模型流程
     * @return 结果
     */
    public int updateMdModelFlow(MdModelFlow mdModelFlow);

    /**
     * 批量删除模型流程
     * 
     * @param flowIds 需要删除的模型流程主键集合
     * @return 结果
     */
    public int deleteMdModelFlowByFlowIds(Long[] flowIds);

    /**
     * 删除模型流程信息
     * 
     * @param flowId 模型流程主键
     * @return 结果
     */
    public int deleteMdModelFlowByFlowId(Long flowId);
}
